Getting started
***************

.. toctree::
   :maxdepth: 1

		Installation <install>
    Configuration <configure>
    Finding data <find_data>
    Installed recipes <recipes>
		Running <run>
		Output <output>
